#!/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
#> This script will install Lucent UMTS components
#> patch: 6.0.9.2.3
#> Usage: install.sh {-help | -install }
#

# Required values defined
export PATCH_VER=6.0.9.2.3
export START_DIR=`pwd`
export SOURCE_DIR=${FLEXPM_HOME}/patches/${PATCH_VER}
export BACKUP_DIR=$START_DIR/Backup

# **************************************************************
# The following are 'standard' routines to be used before
# attempting to apply and upgrade/patch
# **************************************************************
# ***
# Check the essential environment settings have been defined before attempting
# any installation procedures.
# ***
function CheckEnvironment {

  # Check FLEXPM_HOME is defined 
  if [[ -z ${FLEXPM_HOME} || ! -d ${FLEXPM_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check PROSPECT_HOME is defined 
  if [[ -z ${PROSPECT_HOME} || ! -d ${PROSPECT_HOME} ]]; then
    echo ""
    echo "+> Env variable FLEXPM_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check LuUMTS_CS_HOME is defined 
  if [[ -z ${LuUMTS_CS_HOME} || ! -d ${LuUMTS_CS_HOME} ]]; then
    echo ""
    echo "+> Env variable LuUMTS_CS_HOME must be set to appropriate dir before installation."
    echo ""
    exit 1;
  fi
  # Check that the DB_CONNECT string is defined.
  if [[ -z ${DB_CONNECT} ]]; then
    echo ""
    echo "+> Env variable DB_CONNECT must be set to approriate database connection values."
    echo ""
    exit 1;
  fi
  # Check VENDOR pre-requisite
  PRE_REQ=`show_installed | grep 'LuUMTS_CS rev 6.0.9.2.0'`
  if [[ -z ${PRE_REQ} ]]; then
    echo ""
    echo "+> Lucent UMTS_CS (LuUMTS_CS) 6.0.9.2.0 must be installed before applying this patch."
    echo ""
    exit 1;
  fi
  thisUSER=`id | cut -d "(" -f2 | cut -d ")" -f1`
  ps -fu $thisUSER | grep "wmpm -service $WM_PM_PORT" |grep -v "grep" >/dev/null
  if [ $? -eq 0 ]
  then
    echo ""
    echo "+>"` ps -fu $thisUSER | grep "wmpm -service $WM_PM_PORT" |grep -v "grep"`
    echo "+> The middleware is still running, please stop the middleware first."
    echo ""
    exit 1
  fi
}

# **************************************************************
# End of routines and start of main patch
# **************************************************************

# Check that the passed parameters are correct
if [[ $# -ne 1 ]]; then
  echo
  echo "Invalid number of arguments"
  echo
  echo "Usage : $0 {-help | -install }"
  echo
  exit;
fi

case $1 in
  -install)
    echo ""
    date +"+ Patch install started at %T, %D ..."
    echo ""

    # Check env settings
    echo ""
    echo "+ Checking environment ..."
    CheckEnvironment
    echo "+ Environment appears to be OK ..."
    echo ""

    # Install updated components
    if [ ! -d $BACKUP_DIR ]
    then
      mkdir $BACKUP_DIR
    fi
    
    echo
    echo "Registering Lucent ${PATCH_VER} ..."
    chmod +x $FLEXPM_HOME/pm/adm/register
    register start ${SOURCE_DIR}/LuUMTS_CS.build
    echo


    ########################################################
    echo "+ Installing updated files..."
    ########################################################

    cd $SOURCE_DIR/sources

    for new_dir in `find . -type d|cut -c3-`
    do
      if [[ -d ${FLEXPM_BASE}/$new_dir ]]; then
        echo "dir ok: $new_dir"
      else
        echo "create: $new_dir"
        mkdir -p ${FLEXPM_BASE}/$new_dir
      fi
    done

    touch ${BACKUP_DIR}/backup_sources.tar

    cd $SOURCE_DIR/sources

    for new_file in `find . -type f|cut -c3-`
    do
      cd ${FLEXPM_BASE}
      if [[ -f $new_file ]];
      then
        echo "backup: ${FLEXPM_BASE}/$new_file"
        gtar -uf ${BACKUP_DIR}/backup_sources.tar $new_file
        chmod +w $new_file
      fi
      echo "update: ${FLEXPM_BASE}/$new_file"
      cp -p ${SOURCE_DIR}/sources/$new_file $new_file
    done

    cd $LuUMTS_CS_HOME/peik/xml

    touch parser.err
    chmod 777 parser.err

    echo "Running dict_update..."
    cd $LuUMTS_CS_HOME/peik
    make dict_update
    ret=$?

    if [  $ret != 0 ]; then
      echo "+++ Error in dict_update."
      echo "Installation not complete. Please contact IBM Support."
      exit 2
    fi

    echo "Dict_update completed"

    #recompile all invalid object (except for views)...
    echo "+ recompiling any invalid object(s)..."
    chmod u+x $SOURCE_DIR/recompile_schema.sh
    $SOURCE_DIR/recompile_schema.sh

    #recompile all invalid views:
    echo "+ recompiling any invalid view(s)..."
    chmod u+x $SOURCE_DIR/recompile_view.sh
    $SOURCE_DIR/recompile_view.sh

    echo "Re-compilation done."
    echo 
    echo "Updating CallServer loader packages..."
    cd $LuUMTS_CS_HOME/vendor/Lucent/UMTS_CS/1.3/LuUMTS_CS_loader/CallServer0302_pm/config
    make dict_update

    echo
    echo "Completing registration ..."
    register complete ${SOURCE_DIR}/LuUMTS_CS.build

    cd ${START_DIR}

    echo
    date +"Patch is completed at %T, %D ....."
    break
    ;;
  -help)
    echo
    echo "Usage : $0 {-help | -install}"
    echo
    echo "-help      : Display this help text"
    echo "-install   : Install the patch"
    echo
    break
    ;;
  *)
    echo
    echo "Invalid argument supplied"
    echo
    echo "Usage : $0 {-help | -install }"
    echo
    break
    ;;
esac

